@@ -28,6 +28,7 @@
 
 #include "main/settings.h"
 
+extern int strongs_on;
 SWORD_NAMESPACE_START 
 GS_OSISHTMLHREF::MyUserData::MyUserData(const SWModule * module, const SWKey * key):
 BasicFilterUserData(module, key)
@@ -65,14 +66,17 @@ GS_OSISHTMLHREF::GS_OSISHTMLHREF()
 bool
 GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData * userData) {
 	// manually process if it wasn't a simple substitution
+	//g_message(token);
 	if (!substituteToken(buf, token)) {
 		MyUserData     *u = (MyUserData *) userData;
 		XMLTag tag(token);
-
+		
+		
 		if (!tag.getName()) {
 			return false;
 		}
 		// <q> quote
+		//g_message("\ntoken: %s", token);
 		if (!strcmp(tag.getName(), "q")) {
 			SWBuf type = tag.getAttribute("type");
 			SWBuf who = tag.getAttribute("who");
@@ -128,10 +132,8 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 					outTag.appendFormatted("gloss=%s&", val);
 				}
 				if ((attrib = tag.getAttribute("lemma"))) {
-					const int
-					                count = tag.getAttributePartCount("lemma");
-					int
-					                i = (count > 1) ? 0 : -1;	
+					const int  count = tag.getAttributePartCount("lemma", ' ');
+					int  i = (count > 1) ? 0 : -1;	
 					attrValue = "";
 
 					do {
@@ -139,7 +141,7 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 							attrValue += "|";
 						}
 
-						attrib = tag.getAttribute("lemma", i);
+						attrib = tag.getAttribute("lemma", i,' ');
 						if (i < 0) {	// to handle our -1 condition
 							i = 0;
 						}
@@ -153,8 +155,8 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 							
 						if ((*val == 'H') || (*val == 'G')) {
 							++val;
-							attrValue.append(val);
 						}
+							attrValue.append(val);
 					}
 					while (++i < count);
 					
@@ -167,7 +169,7 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 				}
 				if ((attrib = tag.getAttribute("morph"))) {
 					//printf("%s\n",token);
-					const int  count = tag.getAttributePartCount("morph");
+					const int  count = tag.getAttributePartCount("morph", ' ');
 					int i = (count > 1) ? 0 : -1;	// -1 for whole value cuz it's faster, but does the same thing as 0
 					attrValue = "";
 					do {
@@ -175,13 +177,13 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 							attrValue += "|";
 						}
 
-						attrib = tag.getAttribute("morph", i);
+						attrib = tag.getAttribute("morph", i, ' ');
 						if (i < 0) {
 							i = 0;	// to handle our -1 condition
 						}
 						val = strchr(attrib, ':');
 						val = (val) ? (val + 1) : attrib;
-						if (!strncmp(attrib, "x-Robinson", 10)) {	// robinson 
+						if (!strncmp(attrib, "robinson", 8)) {	// robinson 
 							// 
 							// 
 							// codes
@@ -212,7 +214,6 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 #else
 		// <w> tag
 		else if (!strcmp(tag.getName(), "w")) {
- 
 			// start <w> tag
 			if ((!tag.isEmpty()) && (!tag.isEndTag())) {
 				u->w = token;
@@ -222,7 +223,7 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 			else {
 				bool endTag = tag.isEndTag();
 				SWBuf lastText;
-				bool show = true;	// to handle unplaced article in kjv2003-- temporary till combined
+				//bool show = true;	// to handle unplaced article in kjv2003-- temporary till combined
 
 				if (endTag) {
 					tag = u->w.c_str();
@@ -242,11 +243,13 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 					val = (val) ? (val + 1) : attrib;
 					buf.appendFormatted(" %s", val);
 				}
-				if (attrib = tag.getAttribute("lemma")) {
-					int count = tag.getAttributePartCount("lemma");
+					int mycount = 0;
+				if ((attrib = tag.getAttribute("lemma")) && strongs_on) {
+					int count = tag.getAttributePartCount("lemma", ' ');
+				//	g_message("AttributePartCount = %d\nmycount = %d",count,++mycount);
 					int i = (count > 1) ? 0 : -1;		// -1 for whole value cuz it's faster, but does the same thing as 0
 					do {
-						attrib = tag.getAttribute("lemma", i);
+						attrib = tag.getAttribute("lemma", i, ' ');
 						if (i < 0) i = 0;	// to handle our -1 condition
 						val = strchr(attrib, ':');
 						val = (val) ? (val + 1) : attrib;
@@ -258,36 +261,38 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 						const char *val2 = val;
 						if ((strchr("GH", *val)) && (isdigit(val[1])))
 							val2++;
-						if ((!strcmp(val2, "3588")) && (lastText.length() < 1))
-							show = false;
-						else buf.appendFormatted(" <small><em>&lt;<a href=\"passagestudy.jsp?action=showStrongs&type=%s&value=%s\">%s</a>&gt;</em></small> ", 
+						if (!strcmp(val2, "3588"))  gh = "Greek"; // untill kjv module adds G to 3588
+						
+						if (!u->suspendTextPassThru)
+						buf.appendFormatted(" <small><em>&lt;<a href=\"passagestudy.jsp?action=showStrongs&type=%s&value=%s\">%s</a>&gt;</em></small> ", 
 							(gh.length()) ? gh.c_str() : "", 
 							URL::encode(val2).c_str(), 
 							val2);
 						
 					} while (++i < count);
 				}
-				if ((attrib = tag.getAttribute("morph")) && (show)) {
-					SWBuf savelemma = tag.getAttribute("savlm");
+				if ((attrib = tag.getAttribute("morph"))) { // && (show)) {
+					/*SWBuf savelemma = tag.getAttribute("savlm");
 					if ((strstr(savelemma.c_str(), "3588")) && (lastText.length() < 1))
 						show = false;
-					if (show) {
-						int count = tag.getAttributePartCount("morph");
+					if (show) {*/
+						int count = tag.getAttributePartCount("morph", ' ');
 						int i = (count > 1) ? 0 : -1;		// -1 for whole value cuz it's faster, but does the same thing as 0
 						do {
-							attrib = tag.getAttribute("morph", i);
+							attrib = tag.getAttribute("morph", i, ' ');
 							if (i < 0) i = 0;	// to handle our -1 condition
 							val = strchr(attrib, ':');
 							val = (val) ? (val + 1) : attrib;
 							const char *val2 = val;
 							if ((*val == 'T') && (strchr("GH", val[1])) && (isdigit(val[2])))
 								val2+=2;
+						if (!u->suspendTextPassThru)
 							buf.appendFormatted(" <small><em>(<a href=\"passagestudy.jsp?action=showMorph&type=%s&value=%s\">%s</a>)</em></small> ", 
 								URL::encode(tag.getAttribute("morph")).c_str(),
 								URL::encode(val).c_str(), 
 								val2);
 						} while (++i < count);
-					}
+					//}
 				}
 				if (attrib = tag.getAttribute("POS")) {
 					val = strchr(attrib, ':');
@@ -301,6 +306,7 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 		}
 #endif		
 /*************************************************************************************************************/
+		
 		// <note> tag
 		else if (!strcmp(tag.getName(), "note")) {
 			if (!tag.isEndTag()) {
@@ -317,6 +323,7 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 						// to turn
 						// different note
 						// types on or off
+						u->inNote = true;
 						SWBuf footnoteNumber = tag.getAttribute("swordFootnote");
 						VerseKey       *vkey;
 						// see if we have a VerseKey * or descendant
@@ -345,6 +352,7 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 				u->suspendTextPassThru = true;
 			}
 			if (tag.isEndTag()) {
+				u->inNote = false;
 				u->suspendTextPassThru = false;
 			}
 		}
@@ -397,12 +405,18 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 			}
 		}
 		// <milestone type="line"/>
-		else if ((!strcmp(tag.getName(), "milestone"))
-			 && (tag.getAttribute("type"))
-			 && (!strcmp(tag.getAttribute("type"), "line")) 
-			 && !settings.versestyle) {
-			buf += "<br />";
-			userData->supressAdjacentWhitespace = true;
+		// <milestone type="x-p" marker="&#182;"/>
+		else if (!strcmp(tag.getName(), "milestone")&& tag.getAttribute("type")) {
+			if(!strcmp(tag.getAttribute("type"),"x-p")) 
+				if( tag.getAttribute("marker"))
+					buf += tag.getAttribute("marker");
+				else
+					buf +=  "<!p>";
+			else if(!strcmp(tag.getAttribute("type"), "line"))  {
+				buf += "<br />";
+				//g_message("\ntoken: %s\ntag: %s\ntype: %s",token,tag.getName(),tag.getAttribute("type"));
+				userData->supressAdjacentWhitespace = true;
+			}
 		}
 		// <title>
 		else if (!strcmp(tag.getName(), "title")) {
@@ -412,6 +426,33 @@ GS_OSISHTMLHREF::handleToken(SWBuf & buf, const char *token, BasicFilterUserData
 				buf += (settings.versestyle)?"</b>":"</b><br />";
 			}
 		}
+		// divineName  
+		else if (!strcmp(tag.getName(), "divineName")) {
+			SWBuf type = tag.getAttribute("type");
+			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
+				if (type == "x-yhwh") {
+					u->inName = true;
+					u->suspendTextPassThru = true;
+				} else {
+					u->inName = false;
+				}
+			} else if (tag.isEndTag()) {
+				if(u->inName) {
+					char firstChar = *u->lastTextNode.c_str();
+					const char *name = u->lastTextNode.c_str();
+			//g_message("\nverse: %s\ntoken: %s\nname: %s",(char*)u->key->getText(), token,name);
+					++name;
+					buf += firstChar;
+					buf += "<font size=\"-1\">";
+					for(int i=0;i<strlen(name);i++)
+						buf += toupper(name[i]);
+					buf += "</font>";
+					u->inName = false;
+					u->suspendTextPassThru = false;
+				}
+			} 
+		}
+
 		// <hi> hi? hi contrast?
 		else if (!strcmp(tag.getName(), "hi")) {
 			SWBuf type = tag.getAttribute("type");
