@@ -23,14 +23,20 @@
 #endif
 
 #include <swmgr.h>
+#include <swmodule.h>
 #include <localemgr.h>
 #include <swversion.h>
 
-//#ifdef USE_GTKMOZEMBED
+//#ifdef USE_GTKMOZEMBED 
 #include "backend/gs_markupfiltmgr.h"
-//#else
-//#include <markupfiltmgr.h>
 //#endif
+//#ifdef USE_SWORD_SVN
+#include <markupfiltmgr.h>
+//#endif
+
+#ifdef USE_SWORD_SVN
+#include <swlocale.h>
+#endif
 
 #include <gnome.h>
 #include <versekey.h>
@@ -59,8 +65,21 @@ static gchar *f_message = "backend/sword_main.cc line #%d \"%s\" = %s";
 #endif
 
 BackEnd::BackEnd() {
+
+#ifdef USE_GTKMOZEMBED 		
 	main_mgr = new SWMgr(new GS_MarkupFilterMgr(FMT_HTMLHREF));
 	display_mgr = new SWMgr(new GS_MarkupFilterMgr(FMT_HTMLHREF));
+
+#else	
+#ifdef USE_SWORD_SVN
+	main_mgr = new SWMgr(new MarkupFilterMgr(FMT_HTMLHREF));
+	display_mgr = new SWMgr(new MarkupFilterMgr(FMT_HTMLHREF));
+#else
+	main_mgr = new SWMgr(new GS_MarkupFilterMgr(FMT_HTMLHREF));
+	display_mgr = new SWMgr(new GS_MarkupFilterMgr(FMT_HTMLHREF));
+#endif
+#endif
+
 	
 	display_mod = NULL;	
 	tree_key = NULL;	
@@ -68,9 +87,12 @@ BackEnd::BackEnd() {
 	bookDisplay          = 0;
 	dictDisplay          = 0;
 	textDisplay          = 0;
+#ifndef USE_GTKMOZEMBED
+	RTOLDisplay          = 0;
+	dialogRTOLDisplay    = 0;
+#endif
 	entryDisplay         = 0;
 	chapDisplay          = 0;
-	dialogRTOLDisplay    = 0;
 	verselistDisplay     = 0;
 	viewerDisplay        = 0;
 }
@@ -87,13 +109,17 @@ BackEnd::~BackEnd() {
 	if (dictDisplay)
 		delete dictDisplay;
 	if (textDisplay)
-		delete textDisplay;	
+		delete textDisplay;
+#ifndef USE_GTKMOZEMBED
+	if (RTOLDisplay)
+		delete RTOLDisplay;
+	if(dialogRTOLDisplay)
+		delete dialogRTOLDisplay;
+#endif	
 	if(entryDisplay)
 		delete entryDisplay;
 	if(chapDisplay)
 		delete chapDisplay;
-	if(dialogRTOLDisplay)
-		delete dialogRTOLDisplay;
 	if(verselistDisplay)
 		delete verselistDisplay;
 	if(viewerDisplay)
@@ -109,11 +135,15 @@ void BackEnd::init_SWORD(int gsType) {
 					it != display_mgr->Modules.end(); it++) {
 			display_mod = (*it).second;
 			if (!strcmp(display_mod->Type(), TEXT_MODS)) {
+#ifdef USE_GTKMOZEMBED
+				display_mod->setDisplay(textDisplay);
+#else
 				const char *direction = display_mod->getConfigEntry("Direction");
 				if(direction && !strcmp(direction,"RtoL" ))
 					display_mod->setDisplay(RTOLDisplay);
 				else
 					display_mod->setDisplay(textDisplay);
+#endif
 			}
 			if (!strcmp(display_mod->Type(), COMM_MODS)) {
 				display_mod->setDisplay(commDisplay);
@@ -129,11 +159,16 @@ void BackEnd::init_SWORD(int gsType) {
 	} else if(gsType == 1) {
 		for (it = display_mgr->Modules.begin(); it != display_mgr->Modules.end(); it++) {	
 			display_mod = (*it).second;
-			if (!strcmp(display_mod->Type(), TEXT_MODS)) {const char *direction = display_mod->getConfigEntry("Direction");
+			if (!strcmp(display_mod->Type(), TEXT_MODS)) {				
+#ifdef USE_GTKMOZEMBED
+				display_mod->setDisplay(chapDisplay);
+#else
+				const char *direction = display_mod->getConfigEntry("Direction");
 				if(direction && !strcmp(direction,"RtoL" ))
 					display_mod->setDisplay(dialogRTOLDisplay);
 				else
 					display_mod->setDisplay(chapDisplay);
+#endif
 			} else {
 				display_mod->setDisplay(entryDisplay);
 			}
@@ -353,6 +388,31 @@ char *BackEnd::get_render_text(const char *module_name, const char *key) {
 	}
 	return NULL;	
 }
+char *BackEnd::get_raw_text(const char *module_name, const char *key) {
+	SWModule *mod;
+	ModMap::iterator it;	//-- iteratior
+	//-- iterate through the modules until we find modName  
+	it = display_mgr->Modules.find(module_name);
+	//-- if we find the module
+	if (it != display_mgr->Modules.end()) {
+		char *mykey;                                                 
+		gsize bytes_read;
+		gsize bytes_written;
+		GError **error = NULL;		
+		mykey = g_convert(key,
+				     -1,
+				     OLD_CODESET,
+				     UTF_8,
+				     &bytes_read,
+				     &bytes_written,
+				     error);
+		mod = (*it).second;
+		mod->setKey(mykey);
+		g_free(mykey);
+		return strdup((char *) mod->getRawEntry());
+	}
+	return NULL;	
+}
 
 char *BackEnd::render_this_text(const char * module_name, const char * text) {
 	SWModule *mod;
@@ -426,7 +486,8 @@ char *BackEnd::get_valid_key(const char *key) {
 	vkey.AutoNormalize(1);
 	vkey = mykey;       
 	g_free(mykey);
-	mykey = g_convert((char*)vkey.getText(),
+	
+	mykey = g_convert((char*)vkey.getShortText(),
                              -1,
                              UTF_8,
                              OLD_CODESET,
@@ -1078,7 +1139,8 @@ int BackEnd::do_module_index(char *module_name, int is_dialog) {
 	if (!search_mod)
 		return -1;
 	char progressunits = 70;
-	
+	if (!search_mod->hasSearchFramework())
+		return 0;
 	search_mod->createSearchFramework((is_dialog)
 					?main_dialog_search_percent_update
 					:main_sidebar_search_percent_update,
@@ -1092,7 +1154,7 @@ int BackEnd::check_for_optimal_search(char * module_name) {
 	if (!search_mod)
 		return -2;
 	if (search_mod->hasSearchFramework() && search_mod->isSearchOptimallySupported("God", -4, 0, 0))
-		return -4;
+		return -4; // ** indexed search - clucene ** 
 	else
 		return -2; // ** word search **
 }
@@ -1331,41 +1393,22 @@ void BackEnd::save_conf_file_item(const char * file, const char * mod_name, cons
 void BackEnd::save_module_key(char *mod_name, char *key) {
 	SectionMap::iterator section;
 	ConfigEntMap::iterator entry;
-	return; // this needs help
+	char *mod_name_lower =  g_ascii_strdown(mod_name, strlen(mod_name));	
+	char *conffile = g_strdup_printf("%s/%s.conf",main_mgr->configPath,mod_name_lower);
+	SWConfig *myConfig = new SWConfig(conffile);
 	
-	DIR *dir;
-	char buf[256], conffile[256];
-	struct dirent *ent;
-
-//	strcpy(buf, sw.main_mgr->configPath);
-	dir = opendir(buf);
-	if (dir) {		//-- find and update .conf file
-		rewinddir(dir);
-		while ((ent = readdir(dir))) {
-			if ((strcmp(ent->d_name, "."))
-			    && (strcmp(ent->d_name, ".."))) {
-				sprintf(conffile, "%s/%s", buf,
-					ent->d_name);
-				SWConfig *myConfig =
-				    new SWConfig(conffile);
-				section =
-				    myConfig->Sections.find(mod_name);
-				if (section != myConfig->Sections.end()) {
-					entry =
-					    section->second.
-					    find("CipherKey");
-					if (entry !=
-					    section->second.end()) {
-						//-- set cipher key
-						entry->second = key;
-						//-- save config file						    
-						myConfig->Save();
-					}
-				}
-				delete myConfig;
-			}
+	section = myConfig->Sections.find(mod_name);
+	if (section != myConfig->Sections.end()) {
+		entry =  section->second. find("CipherKey");
+		if (entry != section->second.end()) {
+			//-- set cipher key
+			entry->second = key;
+			//-- save config file						    
+			myConfig->Save();
 		}
 	}
-	closedir(dir);
+	free(conffile);
+	free(mod_name_lower);
+	delete myConfig;
 }
 /* end of file */
