@@ -110,8 +110,8 @@ void frontend_init(void)
 	 */
 	if (settings.havebible) {
 		main_check_parallel_modules();
-		//main_set_parallel_options_at_start();
 		main_init_paraellel_view();
+		//main_set_parallel_options_at_start();
 		//gui_create_parallel_popup(get_list(TEXT_DESC_LIST));
 	}
 
@@ -201,7 +201,10 @@ void frontend_display(void)
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
 				       (widgets.viewdicts_item),
 				       settings.showdicts);
-
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
+				       (widgets.viewpreview_item),
+				       settings.showpreview);
+	gui_show_hide_preview(settings.showpreview);
 	/* showing the devotional must come after the the app is shown or
 	 *  it will mess up the sidebar display
 	 */
@@ -268,6 +271,7 @@ void frontend_display(void)
 
 void shutdown_frontend(void)
 {
+	RESULTS *list_item;
 	if(pixbufs->pixbuf_closed)
 		g_object_unref(pixbufs->pixbuf_closed);
 	if(pixbufs->pixbuf_opened)
@@ -283,7 +287,10 @@ void shutdown_frontend(void)
 	/* free verse list used for saving search results */
 	if(list_of_verses) {
 		while(list_of_verses) {
-			g_free(list_of_verses->data);
+			list_item = (RESULTS*)list_of_verses->data;
+			g_free(list_item->module);
+			g_free(list_item->key);
+			g_free(list_item);
 			list_of_verses = g_list_next(list_of_verses);
 		}
 		g_list_free(list_of_verses);
